/*
 *  /MathJax/localization/sk/HelpDialog.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("sk","HelpDialog",{version:"2.7.5",isLoaded:true,strings:{Help:"Pomoc k MathJaxu",MathJax:"*MathJax* je JavaScriptov\u00E1 kni\u017Enica, ktor\u00E1 autorom str\u00E1nok umo\u017E\u0148uje zahrn\u00FA\u0165 do str\u00E1nok matematiku. Ako \u010Ditate\u013E sa nemus\u00EDte o ni\u010D stara\u0165.",Browsers:"*Prehliada\u010De*: MathJax pracuje vo v\u0161etk\u00FDch modern\u00FDch prehliada\u010Doch, vr\u00E1tane IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ a v\u00E4\u010D\u0161ine mobiln\u00FDch prehliada\u010Dov.",Menu:"*Matematick\u00E9 menu*: MathJax prid\u00E1va k rovniciam kontextov\u00E9 menu. Pre zobrazenie menu kliknite prav\u00FDm tla\u010Didlom my\u0161i alebo s podr\u017Ean\u00EDm kl\u00E1vesy Ctrl na ktor\u00FAko\u013Evek matematiku.",ShowMath:"*Zobrazi\u0165 matematiku ako* v\u00E1m umo\u017En\u00ED prehliadnu\u0165 si zdrojov\u00FD k\u00F3d vzorca pre skop\u00EDrovanie (ako MathML alebo v p\u00F4vodnom form\u00E1te).",Settings:"*Nastavenia* v\u00E1m umo\u017E\u0148uj\u00FA prisp\u00F4sobi\u0165 si niektor\u00E9 funkcie MathJaxu, napr. ve\u013Ekos\u0165 matematiky alebo mechanizmy pou\u017E\u00EDvan\u00E9 k zobrazovaniu rovn\u00EDc.",Language:"*Jazyk* v\u00E1m umo\u017En\u00ED zvoli\u0165 si jazyk pou\u017E\u00EDvan\u00FD MathJaxem pre menu a chybov\u00E9 hl\u00E1senia.",Zoom:"*Matematick\u00FD zoom*: Ak v\u00E1m \u010D\u00EDtanie rovnice rob\u00ED probl\u00E9my, Mathjax V\u00E1m umo\u017En\u00ED ich zv\u00E4\u010D\u0161i\u0165, aby ste ju lep\u0161ie videli.",Accessibilty:"*Dostupnos\u0165*: MathJax automaticky funguje s \u010D\u00EDta\u010Dkami obrazovky, aby matematiku spr\u00EDstupnil zrakovo postihnut\u00FDm.",Fonts:"*P\u00EDsma*: MathJax bude pou\u017E\u00EDva\u0165 ist\u00E9 matematick\u00E9 p\u00EDsma, ak ich m\u00E1te v po\u010D\u00EDta\u010Di nain\u0161talovan\u00E9; v opa\u010Dnom pr\u00EDpade pou\u017Eije p\u00EDsma webov\u00E9. Napriek tomu, \u017Ee to nie je nutn\u00E9, lok\u00E1lne nain\u0161talovan\u00E9 p\u00EDsma ur\u00FDchlia s\u00E1dzanie. Odpor\u00FA\u010Dame nain\u0161talova\u0165 [p\u00EDsma STIX](%1).",CloseDialog:"Zavri\u0165 okno s n\u00E1povedou"}});MathJax.Ajax.loadComplete("[MathJax]/localization/sk/HelpDialog.js");
