[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Alfa"}},"key":"1D756"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Beta"}},"key":"1D757"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Gamma"}},"key":"1D758"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Delta"}},"key":"1D759"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Épsilon"}},"key":"1D75A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Zeta"}},"key":"1D75B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Eta"}},"key":"1D75C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Theta"}},"key":"1D75D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Iota"}},"key":"1D75E"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Kappa"}},"key":"1D75F"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Lambda"}},"key":"1D760"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Mi"}},"key":"1D761"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ni"}},"key":"1D762"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Xi"}},"key":"1D763"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ómicron"}},"key":"1D764"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Pi"}},"key":"1D765"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Rho"}},"key":"1D766"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Sigma"}},"key":"1D768"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Tau"}},"key":"1D769"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ípsilon"}},"key":"1D76A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Phi"}},"key":"1D76B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ji"}},"key":"1D76C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Psi"}},"key":"1D76D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Omega"}},"key":"1D76E"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita alfa"}},"key":"1D770"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita beta"}},"key":"1D771"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita gamma"}},"key":"1D772"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita delta"}},"key":"1D773"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita épsilon"}},"key":"1D774"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita zeta"}},"key":"1D775"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita eta"}},"key":"1D776"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita theta"}},"key":"1D777"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita iota"}},"key":"1D778"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita kappa"}},"key":"1D779"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita lambda"}},"key":"1D77A"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita mi"}},"key":"1D77B"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ni"}},"key":"1D77C"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita xi"}},"key":"1D77D"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ómicron"}},"key":"1D77E"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita pi"}},"key":"1D77F"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita rho"}},"key":"1D780"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita final sigma"}},"key":"1D781"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita sigma"}},"key":"1D782"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita tau"}},"key":"1D783"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ípsilon"}},"key":"1D784"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita phi"}},"key":"1D785"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ji"}},"key":"1D786"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita psi"}},"key":"1D787"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita omega"}},"key":"1D788"}]
